Documentation
¶
Overview ¶
Package ui implements UI related functionality and design
Index ¶
Constants ¶
This section is empty.
Variables ¶
var DefaultKeyMap = KeyMap{ Up: key.NewBinding( key.WithKeys("k", "up"), key.WithHelp("↑/k", "up"), ), Down: key.NewBinding( key.WithKeys("j", "down"), key.WithHelp("↓/j", "down"), ), Select: key.NewBinding( key.WithKeys("enter"), key.WithHelp("enter", "select"), ), Back: key.NewBinding( key.WithKeys("esc", "backspace"), key.WithHelp("esc", "back"), ), Tab: key.NewBinding( key.WithKeys("tab"), key.WithHelp("tab", "switch focus"), ), Quit: key.NewBinding( key.WithKeys("q", "ctrl+c"), key.WithHelp("q", "quit"), ), Help: key.NewBinding( key.WithKeys("?"), key.WithHelp("?", "toggle help"), ), PlayPause: key.NewBinding( key.WithKeys("space"), key.WithHelp("space", "play/pause"), ), Next: key.NewBinding( key.WithKeys("n"), key.WithHelp("n", "next"), ), Prev: key.NewBinding( key.WithKeys("p"), key.WithHelp("p", "previous"), ), VolUp: key.NewBinding( key.WithKeys("+", "="), key.WithHelp("+", "volume up"), ), VolDown: key.NewBinding( key.WithKeys("-"), key.WithHelp("-", "volume down"), ), Mute: key.NewBinding( key.WithKeys("m"), key.WithHelp("m", "toggle mute"), ), }
Functions ¶
This section is empty.
Types ¶
type KeyMap ¶
type KeyMap struct {
Up key.Binding
Down key.Binding
Select key.Binding
Back key.Binding
Tab key.Binding
Quit key.Binding
Help key.Binding
PlayPause key.Binding
Next key.Binding
Prev key.Binding
VolUp key.Binding
VolDown key.Binding
Mute key.Binding
}
Directories
¶
| Path | Synopsis |
|---|---|
|
Package detail implements the main widow showing track details
|
Package detail implements the main widow showing track details |
|
Package playerbar implements the UI for the player details
|
Package playerbar implements the UI for the player details |
|
Package sidebar implements the sidebar widget
|
Package sidebar implements the sidebar widget |
|
Package styles implements the lipgloss styles for the approach
|
Package styles implements the lipgloss styles for the approach |
Click to show internal directories.
Click to hide internal directories.